@@ -62,6 +62,9 @@ test_that("ph_aot works with file input", {
 })
 
 test_that("ph_aot fails well", {
+  skip_on_appveyor()
+  skip_on_cran()
+  
   # required inputs
   expect_error(ph_aot(), "argument \"traits\" is missing, with no default")
   expect_error(ph_aot("Adsf"), "argument \"phylo\" is missing, with no default")
@@ -77,4 +80,28 @@ test_that("ph_aot fails well", {
                "trait_contrasts must be of class integer, numeric")
   expect_error(ph_aot("adf", "adsf", ebl_unstconst = "asdff"),
                "ebl_unstconst must be of class logical")
+
+  # first column name must be `name`
+  tt <- traits
+  colnames(tt)[1] <- "penguin"
+  expect_error(ph_aot(tt, phylo_str),
+    "first column name in `traits` must be `name`")
+})
+
+test_that("ph_aot corrects mismatched cases in traits df's", {
+  skip_on_appveyor()
+  skip_on_cran()
+  
+  # mismatch in `traits` data.frame is fixed internally
+  traits_err <- traits
+  traits_err$name <- toupper(traits_err$name)
+  expect_is(ph_aot(traits_err, phylo_str), "list")
+ 
+  # mismatch in `traits` file is fixed internally
+  traitsdf_err <- traits
+  traitsdf_err$name <- toupper(traitsdf_err$name)
+  tfile <- tempfile("trait_")
+  utils::write.table(prep_traits(traitsdf_err), file = tfile,
+    quote = FALSE, row.names = FALSE)
+  expect_is(ph_aot(tfile, phylo_str), "list")
 })
